@@ -75,7 +75,8 @@ static gboolean       info_request_page                   (YelpDocument
                                                            const gchar          *page_id,
                                                            GCancellable         *cancellable,
                                                            YelpDocumentCallback  callback,
-                                                           gpointer              user_data);
+                                                           gpointer              user_data,
+                                                           GDestroyNotify        notify);
 
 /* YelpTransform */
 static void           transform_chunk_ready     (YelpTransform        *transform,
@@ -178,7 +179,8 @@ info_request_page (YelpDocument         *document,
                    const gchar          *page_id,
                    GCancellable         *cancellable,
                    YelpDocumentCallback  callback,
-                   gpointer              user_data)
+                   gpointer              user_data,
+                   GDestroyNotify        notify)
 {
     YelpInfoDocumentPrivate *priv = GET_PRIV (document);
     gchar *docuri;
@@ -193,7 +195,8 @@ info_request_page (YelpDocument         *document,
                                                                              page_id,
                                                                              cancellable,
                                                                              callback,
-                                                                             user_data);
+                                                                             user_data,
+                                                                             notify);
     if (handled) {
         return TRUE;
     }
