@@ -124,7 +124,8 @@ static gboolean       man_request_page                   (YelpDocument
                                                           const gchar            *page_id,
                                                           GCancellable           *cancellable,
                                                           YelpDocumentCallback    callback,
-                                                          gpointer                user_data);
+                                                          gpointer                user_data,
+                                                          GDestroyNotify          notify);
 
 /* YelpTransform */
 static void           transform_chunk_ready              (YelpTransform          *transform,
@@ -203,7 +204,8 @@ man_request_page (YelpDocument         *document,
                   const gchar          *page_id,
                   GCancellable         *cancellable,
                   YelpDocumentCallback  callback,
-                  gpointer              user_data)
+                  gpointer              user_data,
+                  GDestroyNotify        notify)
 {
     YelpManDocumentPrivate *priv = GET_PRIV (document);
     gchar *docuri, *fulluri;
@@ -222,7 +224,8 @@ man_request_page (YelpDocument         *document,
                                                                             page_id,
                                                                             cancellable,
                                                                             callback,
-                                                                            user_data);
+                                                                            user_data,
+                                                                            notify);
     if (handled) {
         return handled;
     }
