@@ -140,19 +140,19 @@ typedef gboolean (*LineParser)(YelpManParser *, GError **);
 #define DECLARE_LINE_PARSER(name) \
     static gboolean (name) (YelpManParser *parser, GError **error);
 
-DECLARE_LINE_PARSER (parse_xf);
-DECLARE_LINE_PARSER (parse_f);
-DECLARE_LINE_PARSER (parse_V);
-DECLARE_LINE_PARSER (parse_H);
-DECLARE_LINE_PARSER (parse_v);
-DECLARE_LINE_PARSER (parse_h);
-DECLARE_LINE_PARSER (parse_text);
-DECLARE_LINE_PARSER (parse_w);
-DECLARE_LINE_PARSER (parse_body_text);
-DECLARE_LINE_PARSER (parse_n);
-DECLARE_LINE_PARSER (parse_N);
-DECLARE_LINE_PARSER (parse_C);
-DECLARE_LINE_PARSER (parse_p);
+DECLARE_LINE_PARSER (parse_xf)
+DECLARE_LINE_PARSER (parse_f)
+DECLARE_LINE_PARSER (parse_V)
+DECLARE_LINE_PARSER (parse_H)
+DECLARE_LINE_PARSER (parse_v)
+DECLARE_LINE_PARSER (parse_h)
+DECLARE_LINE_PARSER (parse_text)
+DECLARE_LINE_PARSER (parse_w)
+DECLARE_LINE_PARSER (parse_body_text)
+DECLARE_LINE_PARSER (parse_n)
+DECLARE_LINE_PARSER (parse_N)
+DECLARE_LINE_PARSER (parse_C)
+DECLARE_LINE_PARSER (parse_p)
 
 /* Declare a sort of alist registry of parsers for different lines. */
 struct LineParsePair
@@ -369,20 +369,25 @@ get_troff (gchar *path, GError **error)
 {
     gint ystdout;
     GError *err = NULL;
-    gchar *argv[] = { "man", "-Z", "-Tutf8", "-EUTF-8", NULL, NULL };
+    const gchar *argv[] = { "man", "-Z", "-Tutf8", "-EUTF-8", path, NULL };
+    gchar **my_argv;
 
-    argv[4] = path;
+    /* g_strdupv() should accept a "const gchar **". */
+    my_argv = g_strdupv ((gchar **) argv);
 
-    if (!g_spawn_async_with_pipes (NULL, argv, NULL,
+    if (!g_spawn_async_with_pipes (NULL, my_argv, NULL,
                                    G_SPAWN_SEARCH_PATH, NULL, NULL,
                                    NULL, NULL, &ystdout, NULL, &err)) {
         /* We failed to run the man program. Return a "Huh?" error. */
         *error = g_error_new (YELP_ERROR, YELP_ERROR_UNKNOWN,
                               "%s", err->message);
         g_error_free (err);
+        g_strfreev (my_argv);
         return NULL;
     }
 
+    g_strfreev (my_argv);
+
     return (GInputStream*) g_unix_input_stream_new (ystdout, TRUE);
 }
 
@@ -457,7 +462,7 @@ static void
 set_font_register (YelpManParser *parser, guint k, const gchar* name)
 {
     if (k > MAN_FONTS) {
-        g_warning ("Tried to set nonexistant font register %d to %s",
+        g_warning ("Tried to set nonexistant font register %u to %s",
                    k, name);
         return;
     }
@@ -472,7 +477,7 @@ get_font (const YelpManParser *parser)
     if (k > MAN_FONTS ||
         parser->font_registers[k] == NULL) {
 
-        g_warning ("Tried to get nonexistant font register %d", k);
+        g_warning ("Tried to get nonexistant font register %u", k);
 
         return "";
     }
@@ -501,10 +506,12 @@ get_font (const YelpManParser *parser)
 static gboolean
 parser_parse_line (YelpManParser *parser, GError **error)
 {
+    const struct LineParsePair *p;
+
     if (parser->line_no <= 3)
         return parse_prologue_line (parser, error);
 
-    const struct LineParsePair *p = line_parsers;
+    p = line_parsers;
     while (p->handler != NULL) {
         if (g_str_has_prefix (parser->buffer, p->prefix)) {
             return p->handler(parser, error);
@@ -1046,7 +1053,7 @@ right_truncate_common (gchar *dst, const gchar *src)
     dst += len_dst - 1;
     src += len_src - 1;
 
-    while (k >= 0) {
+    while (k > 0) {
         if (*dst != *src) break;
         *dst = '\0';
 
@@ -1376,7 +1383,7 @@ fixup_links (YelpManParser *parser,
     xmlXPathContextPtr context;
     xmlXPathObjectPtr path_obj;
     xmlNodeSetPtr nodeset;
-    guint i;
+    gint i;
 
     context = xmlXPathNewContext (parser->doc);
     g_return_if_fail (context);
