@@ -43,7 +43,6 @@ static void     search_entry_set_property    (GObject           *object,
 					      GParamSpec        *pspec);
 
 /* Signals */
-static void     search_entry_location_selected (YelpSearchEntry *entry);
 static void     search_entry_search_activated  (YelpSearchEntry *entry);
 static void     search_entry_bookmark_clicked  (YelpSearchEntry *entry);
 
@@ -170,8 +169,8 @@ yelp_search_entry_class_init (YelpSearchEntryClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_VIEW,
                                      g_param_spec_object ("view",
-							  _("View"),
-							  _("A YelpView instance to control"),
+							  "View",
+							  "A YelpView instance to control",
                                                           YELP_TYPE_VIEW,
                                                           G_PARAM_CONSTRUCT_ONLY |
 							  G_PARAM_READWRITE |
@@ -186,8 +185,8 @@ yelp_search_entry_class_init (YelpSearchEntryClass *klass)
     g_object_class_install_property (object_class,
                                      PROP_BOOKMARKS,
                                      g_param_spec_object ("bookmarks",
-							  _("Bookmarks"),
-							  _("A YelpBookmarks implementation instance"),
+							  "Bookmarks",
+							  "A YelpBookmarks implementation instance",
                                                           YELP_TYPE_BOOKMARKS,
                                                           G_PARAM_CONSTRUCT_ONLY |
 							  G_PARAM_READWRITE |
@@ -202,15 +201,11 @@ yelp_search_entry_class_init (YelpSearchEntryClass *klass)
 static void
 yelp_search_entry_init (YelpSearchEntry *entry)
 {
-    YelpSearchEntryPrivate *priv = GET_PRIV (entry);
 }
 
 static void
 search_entry_constructed (GObject *object)
 {
-    GtkCellRenderer *bookmark_cell;
-    GList *cells;
-    GtkTreeIter iter;
     YelpSearchEntryPrivate *priv = GET_PRIV (object);
 
     g_signal_connect (object, "activate",
@@ -388,7 +383,6 @@ static void
 entry_activate_cb (GtkEntry  *text_entry,
                    gpointer   user_data)
 {
-    YelpSearchEntryPrivate *priv = GET_PRIV (user_data);
     gchar *text = g_strdup (gtk_entry_get_text (text_entry));
 
     if (text == NULL || strlen(text) == 0)
@@ -416,7 +410,7 @@ cell_set_completion_bookmark_icon (GtkCellLayout     *layout,
 
         if (page_id && yelp_bookmarks_is_bookmarked (priv->bookmarks,
                                                      priv->completion_uri, page_id))
-            g_object_set (cell, "icon-name", "yelp-bookmark-remove-symbolic", NULL);
+            g_object_set (cell, "icon-name", "user-bookmarks-symbolic", NULL);
         else
             g_object_set (cell, "icon-name", NULL, NULL);
 
@@ -433,7 +427,6 @@ cell_set_completion_text_cell (GtkCellLayout     *layout,
 {
     gchar *title;
     gint flags;
-    YelpSearchEntryPrivate *priv = GET_PRIV (entry);
 
     gtk_tree_model_get (model, iter, COMPLETION_COL_FLAGS, &flags, -1);
     if (flags & COMPLETION_FLAG_ACTIVATE_SEARCH) {
@@ -463,7 +456,6 @@ entry_match_func (GtkEntryCompletion *completion,
     gchar **strs;
     gint flags;
     GtkTreeModel *model = gtk_entry_completion_get_model (completion);
-    YelpSearchEntryPrivate *priv = GET_PRIV (entry);
     static GRegex *nonword = NULL;
 
     if (nonword == NULL)
@@ -587,7 +579,6 @@ view_loaded (YelpView          *view,
     gchar **ids;
     gint i;
     GtkTreeIter iter;
-    gint flags;
     YelpUri *uri;
     gchar *doc_uri;
     GtkTreeModel *completion;
